@@ -760,7 +760,9 @@ class Script:
                 self.add_options(profilefile)
 
             profilefile.write('export WORKING_DIR={}\n'.format(self.work_dir))
-            profilefile.write('mkdir ${WORKING_DIR}\n')
+            profilefile.write('if [ ! -d  "${WORKING_DIR}" ]; then\n')
+            profilefile.write('  mkdir ${WORKING_DIR}\n')
+            profilefile.write('fi\n')
             if self.queue_system is None:
                 profilefile.write('cd ${WORKING_DIR}\n')
             profilefile.write('\n')
